@@ -26,8 +26,8 @@ def sql(key):
         'dataType': {'sql': "SELECT dataType From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
         'indexID': {'sql': "SELECT id From IndexParams;", 'database': 'AnyRobot'},
         'indexName': {'sql': "SELECT indexName From IndexParams;", 'database': 'AnyRobot'},
-        'StreamId': {'sql': "SELECT name From DataStream;", 'database': 'AnyRobot'},
-        'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName="所有日志";', 'database': 'AnyRobot'},
+        'StreamId': {'sql': "SELECT id From DataStream;", 'database': 'AnyRobot'},
+        'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName!="所有日志";', 'database': 'AnyRobot'},
         'RoleId': {'sql': 'SELECT roleId From Role where roleName ="admin";', 'database': 'AnyRobot'},
         'tagGroupID': {'sql': "SELECT id From TagGroup;", 'database': 'AnyRobot'},
         'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
